@@ -1,32 +1,34 @@
 ### R code from vignette source 'Trees.Rnw'
 
 ###################################################
-### code chunk number 1: Trees.Rnw:48-50
+### code chunk number 1: Trees.Rnw:49-52
 ###################################################
 options(width=70)
 foo <- packageDescription("phangorn")
+options("show.signif.stars" = FALSE)
 
 
 ###################################################
-### code chunk number 2: Trees.Rnw:66-68
+### code chunk number 2: Trees.Rnw:68-71
 ###################################################
 library(phangorn)
-primates = read.phyDat("primates.dna", format="phylip", type="DNA")
+primates <- read.phyDat("primates.dna", format="phylip", 
+    type="DNA")
 
 
 ###################################################
-### code chunk number 3: Trees.Rnw:75-78
+### code chunk number 3: Trees.Rnw:77-80
 ###################################################
-dm = dist.dna(as.DNAbin(primates))
-treeUPGMA = upgma(dm)
-treeNJ = NJ(dm)
+dm  <- dist.ml(primates)
+treeUPGMA  <- upgma(dm)
+treeNJ  <- NJ(dm)
 
 
 ###################################################
 ### code chunk number 4: plotNJ
 ###################################################
 layout(matrix(c(1,2), 2, 1), height=c(1,2))
-par(mar = c(.1,.1,.1,.1))
+par(mar = c(0,0,2,0)+ 0.1)
 plot(treeUPGMA, main="UPGMA")
 plot(treeNJ, "unrooted", main="NJ")
 
@@ -36,101 +38,111 @@ plot(treeNJ, "unrooted", main="NJ")
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 layout(matrix(c(1,2), 2, 1), height=c(1,2))
-par(mar = c(.1,.1,.1,.1))
+par(mar = c(0,0,2,0)+ 0.1)
 plot(treeUPGMA, main="UPGMA")
 plot(treeNJ, "unrooted", main="NJ")
 
 
 ###################################################
-### code chunk number 6: Trees.Rnw:100-102
+### code chunk number 6: Trees.Rnw:102-104
 ###################################################
 parsimony(treeUPGMA, primates)
 parsimony(treeNJ, primates)
 
 
 ###################################################
-### code chunk number 7: Trees.Rnw:105-108
+### code chunk number 7: Trees.Rnw:107-110
 ###################################################
-treePars = optim.parsimony(treeUPGMA, primates)
-treeRatchet = pratchet(primates, trace = 0)
+treePars  <- optim.parsimony(treeUPGMA, primates)
+treeRatchet  <- pratchet(primates, trace = 0)
 parsimony(c(treePars, treeRatchet), primates)
 
 
 ###################################################
-### code chunk number 8: Trees.Rnw:111-112 (eval = FALSE)
+### code chunk number 8: Trees.Rnw:113-114 (eval = FALSE)
 ###################################################
 ## (trees <- bab(subset(primates,1:10)))
 
 
 ###################################################
-### code chunk number 9: Trees.Rnw:118-120
+### code chunk number 9: Trees.Rnw:120-122
 ###################################################
 fit = pml(treeNJ, data=primates)
 fit
 
 
 ###################################################
-### code chunk number 10: Trees.Rnw:123-124
+### code chunk number 10: Trees.Rnw:125-126
 ###################################################
 methods(class="pml")
 
 
 ###################################################
-### code chunk number 11: Trees.Rnw:127-129
+### code chunk number 11: Trees.Rnw:129-131
 ###################################################
-fitJC = optim.pml(fit, TRUE)
+fitJC  <- optim.pml(fit, TRUE)
 logLik(fitJC)
 
 
 ###################################################
-### code chunk number 12: Trees.Rnw:132-136
+### code chunk number 12: Trees.Rnw:134-138
 ###################################################
-fitGTR = update(fit, k=4, inv=0.2) 
-fitGTR = optim.pml(fitGTR, TRUE,TRUE, TRUE, TRUE, TRUE, 
-    control = pml.control(trace = 0))
+fitGTR <- update(fit, k=4, inv=0.2) 
+fitGTR <- optim.pml(fitGTR, model="GTR", optInv=TRUE, optGamma=TRUE, 
+    rearrangement = "NNI", control = pml.control(trace = 0))
 fitGTR 
 
 
 ###################################################
-### code chunk number 13: Trees.Rnw:139-140
+### code chunk number 13: Trees.Rnw:141-144
+###################################################
+fitGTR <- optim.pml(fitGTR, model="GTR", optInv=TRUE, optGamma=TRUE, 
+    rearrangement = "stochastic", control = pml.control(trace = 0))
+fitGTR 
+
+
+###################################################
+### code chunk number 14: Trees.Rnw:148-149
 ###################################################
 anova(fitJC, fitGTR) 
 
 
 ###################################################
-### code chunk number 14: Trees.Rnw:143-145
-###################################################
-AIC(fitGTR) 
-AIC(fitJC)
-
-
-###################################################
-### code chunk number 15: Trees.Rnw:148-149
+### code chunk number 15: Trees.Rnw:152-153
 ###################################################
 SH.test(fitGTR, fitJC) 
 
 
 ###################################################
-### code chunk number 16: Trees.Rnw:152-153
+### code chunk number 16: Trees.Rnw:156-160
+###################################################
+AIC(fitJC)
+AIC(fitGTR) 
+AICc(fitGTR) 
+BIC(fitGTR) 
+
+
+###################################################
+### code chunk number 17: Trees.Rnw:163-164
 ###################################################
 load("Trees.RData")
 
 
 ###################################################
-### code chunk number 17: Trees.Rnw:155-156 (eval = FALSE)
+### code chunk number 18: Trees.Rnw:166-167 (eval = FALSE)
 ###################################################
 ## mt = modelTest(primates)
 
 
 ###################################################
-### code chunk number 18: Trees.Rnw:160-162
+### code chunk number 19: Trees.Rnw:171-173
 ###################################################
 library(xtable)
-xtable(mt, caption="Summary table of modelTest", label="tab:modelTest")
+print(xtable(mt, caption="Summary table of modelTest", label="tab:modelTest"), include.rownames=FALSE)
 
 
 ###################################################
-### code chunk number 19: Trees.Rnw:166-169
+### code chunk number 20: Trees.Rnw:177-180
 ###################################################
 env <- attr(mt, "env")
 ls(envir=env)
@@ -138,83 +150,106 @@ ls(envir=env)
 
 
 ###################################################
-### code chunk number 20: Trees.Rnw:173-175 (eval = FALSE)
+### code chunk number 21: Trees.Rnw:183-185 (eval = FALSE)
 ###################################################
 ## bs = bootstrap.pml(fitJC, bs=100, optNni=TRUE, 
 ##     control = pml.control(trace = 0))
 
 
 ###################################################
-### code chunk number 21: plotBS
+### code chunk number 22: plotBS
 ###################################################
-par(mar=c(.1,.1,.1,.1))
-plotBS(fitJC$tree, bs)
+par(mfrow=c(2,1))
+par(mar=c(1,1,3,1))
+plotBS(midpoint(fitJC$tree), bs, p = 50, type="p")
+title("a)")
+cnet <- consensusNet(bs, p=0.2)
+plot(cnet, "2D", show.edge.label=TRUE)
+title("b)")
 
 
 ###################################################
-### code chunk number 22: figBS
+### code chunk number 23: figBS
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
-par(mar=c(.1,.1,.1,.1))
-plotBS(fitJC$tree, bs)
+par(mfrow=c(2,1))
+par(mar=c(1,1,3,1))
+plotBS(midpoint(fitJC$tree), bs, p = 50, type="p")
+title("a)")
+cnet <- consensusNet(bs, p=0.2)
+plot(cnet, "2D", show.edge.label=TRUE)
+title("b)")
 
 
 ###################################################
-### code chunk number 23: Trees.Rnw:199-201
+### code chunk number 24: Trees.Rnw:216-218
 ###################################################
 options(prompt=" ")
 options(continue="  ")
 
 
 ###################################################
-### code chunk number 24: Trees.Rnw:203-226 (eval = FALSE)
+### code chunk number 25: Trees.Rnw:220-249 (eval = FALSE)
 ###################################################
-## library(parallel) # supports parallel computing
 ## library(phangorn)
 ## file="myfile"
 ## dat = read.phyDat(file)
-## dm = dist.ml(dat)
+## dm = dist.ml(dat, "F81")
 ## tree = NJ(dm)
 ## # as alternative for a starting tree:
-## tree <- pratchet(dat) 
+## tree <- pratchet(dat)          # parsimony tree 
+## tree <- nnls.phylo(tree, dm)   # need edge weights
 ## 
-## # 1. alternative: estimate an GTR model
-## fitStart = pml(tree, dat, k=4, inv=.2)
-## fit = optim.pml(fitStart, TRUE, TRUE, TRUE, TRUE, TRUE) 
+## 
+## # 1. alternative: quick and dirty: GTR + G + NNI
+## fitStart = pml(tree, dat, k=4)
+## fit = optim.pml(fitStart, model="GTR", optGamma=TRUE, rearrangement="NNI") 
 ##  
-## # 2. alternative: modelTest  
-## (mt <- modelTest(dat, multicore=TRUE)) 
-## mt$Model[which.min(mt$BIC)]
-## # choose best model from the table, assume now GTR+G+I
+## # 2. alternative: preper with modelTest  
+## mt <- modelTest(dat, tree=tree, multicore=TRUE)
+## mt[order(mt$AICc),]
+## # choose best model from the table according to AICc
+## bestmodel <- mt$Model[which.min(mt$AICc)]
+## 
 ## env = attr(mt, "env")
 ## fitStart = eval(get("GTR+G+I", env), env) 
-## fitStart = eval(get(mt$Model[which.min(mt$BIC)], env), env) 
-## fit = optim.pml(fitStart, optNni=TRUE, optGamma=TRUE, optInv=TRUE, 
-##     model="GTR")
+## 
+## # or let R search the table
+## fitStart = eval(get(bestmodel, env), env) 
+## # equivalent to:   fitStart = eval(get("GTR+G+I", env), env) 
+## fit = optim.pml(fitStart, rearrangement = "stochastic", 
+##     optGamma=TRUE, optInv=TRUE, model="GTR")
 ## bs = bootstrap.pml(fit, bs=100, optNni=TRUE, multicore=TRUE)
 
 
 ###################################################
-### code chunk number 25: Trees.Rnw:230-244 (eval = FALSE)
+### code chunk number 26: Trees.Rnw:255-276 (eval = FALSE)
 ###################################################
-## library(parallel) # supports parallel computing
 ## library(phangorn)
 ## file="myfile"
 ## dat = read.phyDat(file, type = "AA")
 ## dm = dist.ml(dat, model="JTT")
 ## tree = NJ(dm)
 ## 
-## (mt <- modelTest(dat, model=c("JTT", "LG", "WAG"), multicore=TRUE)) 
+## # parallel will only work safely from command line 
+## # and not at all windows
+## (mt <- modelTest(dat, model=c("JTT", "LG", "WAG"), 
+##     multicore=TRUE)) 
+## # run all available amino acid models
+## (mt <- modelTest(dat, model="all", multicore=TRUE))
+## 
 ## fitStart = eval(get(mt$Model[which.min(mt$BIC)], env), env) 
 ## 
 ## fitNJ = pml(tree, dat, model="JTT", k=4, inv=.2)
-## fit = optim.pml(fitNJ, optNni=TRUE, optInv=TRUE, optGamma=TRUE)
+## fit = optim.pml(fitNJ, rearrangement = "stochastic", 
+##     optInv=TRUE, optGamma=TRUE)
 ## fit
+## 
 ## bs = bootstrap.pml(fit, bs=100, optNni=TRUE, multicore=TRUE)
 
 
 ###################################################
-### code chunk number 26: Trees.Rnw:252-253
+### code chunk number 27: Trees.Rnw:288-289
 ###################################################
 toLatex(sessionInfo())
 
